// src/useLaze.ts
import { useFreshLazyRef, useReactiveRef } from "@lyonph/react-hooks";
import {
  useDebugValue,
  useEffect,
  useState
} from "react";
function useLaze(options) {
  const [visible, setVisible] = useState(false);
  const ref = useReactiveRef(() => null);
  const { current } = ref;
  const refreshRef = useFreshLazyRef(() => options == null ? void 0 : options.refresh, options == null ? void 0 : options.refresh);
  useEffect(() => {
    setVisible(false);
    if (current) {
      const observer = new IntersectionObserver((entries) => {
        entries.forEach((entry) => {
          if (entry.target === current) {
            if (refreshRef.current) {
              setVisible(entry.isIntersecting);
            } else if (entry.isIntersecting) {
              setVisible(true);
              observer.disconnect();
            }
          }
        });
      });
      observer.observe(current);
      return () => {
        observer.unobserve(current);
        observer.disconnect();
      };
    }
    return void 0;
  }, [current, refreshRef]);
  const value = {
    ref,
    visible
  };
  useDebugValue(value);
  return value;
}
export {
  useLaze as default
};
//# sourceMappingURL=index.js.map
